﻿using SewingDressesContracts.BindingModels;
using SewingDressesContracts.ViewModels;
using SewingDressesDataModels.Enums;
using SewingDressesDataModels.Models;
using System.Data;
using System.Xml.Linq;

namespace SewingDressesFileImplement.Models
{
    public class Order : IOrderModel
    {
        public int Id { get; private set; }
        public int DressId { get; private set; }
        public int Count { get; private set; }
        public double Sum { get; private set; }
        public OrderStatus Status { get; private set; }
        public DateTime DateCreate { get; private set; } = DateTime.Now;
        public DateTime? DateImplement { get; private set;}

        public static Order? Create(OrderBindingModel model)
        {
            if (model == null)
            {
                return null;
            }
            return new Order()
            {
                Id = model.Id,
                DressId = model.DressId,
                Count = model.Count,
                Sum = model.Sum,
                Status = model.Status,
                DateCreate = model.DateCreate
            };
        }
        public static Order? Create(XElement element)
        {
            if (element == null)
            {
                return null;
            }
            return new Order()
            {
                Id = Convert.ToInt32(element.Attribute("Id")!.Value),
                DressId = Convert.ToInt32(element.Element("DressId")!.Value),
                Count = Convert.ToInt32(element.Element("Count")!.Value),
                Sum = Convert.ToInt32(element.Element("Sum")!.Value),
                Status = (OrderStatus)Convert.ToInt32(element.Element("Status")!.Value),
                DateCreate = Convert.ToDateTime(element.Element("DateCreate")?.Value)
            };
        }
        public void Update(OrderBindingModel model)
        {
            if (model == null)
            {
                return;
            }
            Id = model.Id;
            DressId = model.DressId;
            Count = model.Count;
            Sum = model.Sum;
            Status = model.Status;
            DateCreate = model.DateCreate;
            DateImplement = model.DateImplement;
        }
        public OrderViewModel GetViewModel => new()
        {
            Id = Id,
            DressId = DressId,
            Count = Count,
            Sum = Sum,
            Status = Status,
            DateCreate = DateCreate,
            DateImplement = DateImplement
        };
        public XElement GetXElement => new("Order",
            new XAttribute("Id", Id),
            new XElement("DressId", DressId),
            new XElement("Count", DressId),
            new XElement("Sum", DressId),
            new XElement("Status", DressId),
            new XElement("DateCreate", DressId),
            new XElement("DateImplement", DateImplement));
    }
}
